:mod:`cf.ipc` -- Simple UNIX socket server to handle multiple instances.
------------------------------------------------------------------------

.. automodule:: cf.ipc
   :members:
   :synopsis: Simple UNIX socket server to handle multiple instances.
